##  Additional Settings
In addition to the options mentioned above, you can configure the following settings:
  * Data Privacy: You can choose whether you are able to search for user subscriptions on name basis ("Relaxed") or if you just see them while looking explicitly on the Fact Sheet ("Normal").
  * Completion Score: Toggle to enable or disable the visibility of the Fact Sheet completion score in your workspace. To learn more, see [Fact Sheet Completeness](https://help.sap.com/docs/leanix/ea/fact-sheet-completeness?locale=en-US&state=PRODUCTION&version=CLOUD "The fact sheet completion score measures the extent of required data filled out for a fact sheet, ensuring data accuracy and completeness. It is based on assigned weights to fields, subsections, and sections.")
  * Getting Started Guide: Link that leads you to information on how to getting started with SAP LeanIX. By default it will lead you to the SAP LeanIX product documentation. But you are able to link your own content.
  * Documentation: Link will by default lead you to the SAP LeanIX product documentation. You could change this link, although we strongly recommend to keep it, as this page is a valuable source and will be updated regularly.
  * Help Tours: If you check this box, every user will be guided through our "Help Tour", if this has not been started before.
